Function opaque_pointer::c::ref_str[]

pub unsafe fn ref_str<'a>(
    string: *const c_char
) -> Result<&'a str, PointerError>
👎 Deprecated since 0.8.1:

Use std::ffi::CStr

Convert a reference to a C string into a static reference to Rust str.

Safety

The pointer must be a valid reference or behavior is undefined.

Errors

If the C string is not a valid UTF-8 string.