Module opaque_pointer::error [−]
Opaque pointers errors.
Enums
| PointerError | Errors that can be detected by the functions of this crate. |
Opaque pointers errors.
| PointerError | Errors that can be detected by the functions of this crate. |