Enum opaque_pointer::error::PointerError [−]
pub enum PointerError {
Null,
Invalid,
Utf8Error(Utf8Error),
}Expand description
Errors that can be detected by the functions of this crate.
Of course, invalid address can not be detected, then it’s unsafe yet.
Variants
Null
Invalid
A pointer that was not previously lent to the FFI user.
Utf8Error(Utf8Error)
Tuple Fields
0: Utf8ErrorTrying to convert to &str a C string which content is not valid UTF-8.