Function opaque_pointer::free[]

pub unsafe fn free<T>(pointer: *mut T)
👎 Deprecated since 0.7.2:

Use own_back<T>() instead

Call to own_back<T>(pointer: *mut T) ignoring the result.

This ignore null pointers without an error.

Safety

Invalid pointer or call it twice could cause an undefined behavior or heap error and a crash.