[][src]Function opaque_pointer::own_back

pub unsafe fn own_back<T>(pointer: *mut T) -> T

Own back from a raw pointer to use Rust ownership as usually.

Safety

The pointer must be a valid reference and never call it twice or behavior is undefined.

That could produce a HEAP error that produce a crash.