opaque_pointer::c
pub unsafe fn ref_str<'a>( string: *const c_char) -> Result<&'a str, PointerError>
Convert a reference to a C string into a static reference to Rust str.
str
The pointer must be a valid reference or behavior is undefined.
If the C string is not a valid UTF-8 string.