Enum opaque_pointer::error::PointerError [−]
pub enum PointerError {
Null,
Invalid,
Utf8Error(Utf8Error),
}Errors that can be detected by the functions of this crate.
Of course, invalid address can not be detected, then it’s unsafe yet.
Variants
A pointer that was not previously lent to the FFI user.
Utf8Error(Utf8Error)Trying to convert to &str a C string which content is not valid UTF-8.