Enum opaque_pointer::error::PointerError[]

pub enum PointerError {
    NulPointer,
    Utf8Error(Utf8Error),
}

Errors that can be detected by the functions of this crate.

Of course, invalid address can not be detected, then it’s unsafe yet.

Variants

NulPointer
Utf8Error(Utf8Error)

Trying to convert to &str a C string which content is not valid UTF-8.